@@ -29,9 +29,7 @@
 #include <KgThemeProvider>
 #include <KNotification>
 #include <KRandomSequence>
-#include <KLocale>
-
-#include <KDebug>
+#include <KLocalizedString>
 
 #include <QEasingCurve>
 #include <QGraphicsColorizeEffect>
@@ -47,7 +45,7 @@ static KgThemeProvider* provider()
         Settings::self()->config()->name() == QLatin1String("ksamerc")
         ? QLatin1String("ksame") : QLatin1String("default");
     KgThemeProvider* prov = new KgThemeProvider;
-    prov->discoverThemes("appdata", QLatin1String("themes"), defaultTheme);
+    prov->discoverThemes("appdata", QStringLiteral("themes"), defaultTheme);
     return prov;
 }
 
@@ -67,12 +65,12 @@ m_isPaused(false),
 m_isFinished(false),
 m_animation(new QSequentialAnimationGroup)
 {
-    connect( &m_undoStack, SIGNAL(canUndoChanged(bool)), this, SIGNAL(canUndoChanged(bool)) );
-    connect( &m_undoStack, SIGNAL(canRedoChanged(bool)), this, SIGNAL(canRedoChanged(bool)) );
-    connect( this, SIGNAL(sceneRectChanged(QRectF)), SLOT(resize(QRectF)) );
+    connect(&m_undoStack, &QUndoStack::canUndoChanged, this, &GameScene::canUndoChanged);
+    connect(&m_undoStack, &QUndoStack::canRedoChanged, this, &GameScene::canRedoChanged);
+    connect(this, &GameScene::sceneRectChanged, this, &GameScene::resize);
 
-    connect( m_animation, SIGNAL(finished()), this, SLOT(updateScene()) );
-    connect( m_animation, SIGNAL(finished()), this, SLOT(checkGameFinished()) );
+    connect(m_animation, &QSequentialAnimationGroup::finished, this, &GameScene::updateScene);
+    connect(m_animation, &QSequentialAnimationGroup::finished, this, &GameScene::checkGameFinished);
 
     // init messenger
     m_messenger->setMessageOpacity( 0.8 );
@@ -120,9 +118,9 @@ void GameScene::startNewGame( int pwc, int phc, int colorCount, int gameId )
         for ( int i = 0; i < PWC; ++i ) {
             // piece item
             Piece* item = new Piece( &m_renderer, i, j, s.getLong( m_colorCount ) );
-            connect( item, SIGNAL(pieceClicked(int,int)), this, SLOT(removePieces(int,int)) );
-            connect( item, SIGNAL(pieceHovered(int,int)), this, SLOT(highlightPieces(int,int)) );
-            connect( item, SIGNAL(pieceUnhovered(int,int)), this, SLOT(unhighlightPieces(int,int)) );
+            connect(item, &Piece::pieceClicked, this, &GameScene::removePieces);
+            connect(item, &Piece::pieceHovered, this, &GameScene::highlightPieces);
+            connect(item, &Piece::pieceUnhovered, this, &GameScene::unhighlightPieces);
             m_pieces << item;
             addItem( item );
 
@@ -170,7 +168,7 @@ void GameScene::loadGame( const KConfigGroup& config )
 
     // execute the history
     for ( int i = 0; i < moveCount; ++i ) {
-        QList<int> move = config.readEntry( QString( QLatin1String( "Move_%1" ) ).arg( i ), QList<int>() );
+        QList<int> move = config.readEntry( QStringLiteral( "Move_%1" ).arg( i ), QList<int>() );
         if ( move.count() != 2 ) {
             qWarning() << "Unexpected undo command structure.";
             return;
@@ -218,7 +216,7 @@ void GameScene::saveGame( KConfigGroup& config ) const
         Piece* clickPiece = static_cast<const HidePiece*>(click)->m_piece;
         QList<int> move;
         move << clickPiece->m_x << clickPiece->m_y;
-        config.writeEntry( QString( QLatin1String( "Move_%1" ) ).arg( i ), move );
+        config.writeEntry( QStringLiteral( "Move_%1" ).arg( i ), move );
     }
 }
 
@@ -349,7 +347,7 @@ void GameScene::checkGameFinished()
     emit remainCountChanged( remain );
     bool finished = isGameFinished();
     if ( finished && m_isFinished != finished ) {
-        KNotification::event( QLatin1String( "gamefinished" ) );
+        KNotification::event( QStringLiteral( "gamefinished" ) );
         m_messenger->showMessage( i18n( "game finished" ) , KGamePopupItem::Center );
         emit canUndoChanged( false );
         emit canRedoChanged( false );
@@ -467,7 +465,7 @@ void GameScene::removePieces( int x, int y )
     unhighlightPieces( x, y );
 
     int index = y * PWC + x;
-    m_undoStack.beginMacro( QLatin1String( "Remove pieces" ) );
+    m_undoStack.beginMacro( QStringLiteral( "Remove pieces" ) );
     m_undoStack.push( new HidePiece( m_pieces[index] ) );
 
     traverseNeighbors( x-1, y, m_pieces[index]->m_color, &GameScene::removePiece );// check left neighbor
@@ -486,8 +484,8 @@ void GameScene::removePieces( int x, int y )
     int gameAreaHeight = PHC * elementsSize;
     int yShift = ( sceneRect().height() - gameAreaHeight ) / 2;
 
-    QParallelAnimationGroup* gravityAnimationGroup = NULL;
-    QParallelAnimationGroup* removeColumnsAnimationGroup = NULL;
+    QParallelAnimationGroup* gravityAnimationGroup = nullptr;
+    QParallelAnimationGroup* removeColumnsAnimationGroup = nullptr;
     if ( m_enableAnimation ) {
         // remove previous animations if any
         m_animation->clear();
@@ -572,7 +570,7 @@ void GameScene::removePieces( int x, int y )
     }
 
     m_undoStack.endMacro();
-    KNotification::event( QLatin1String( "remove" ) );
+    KNotification::event( QStringLiteral( "remove" ) );
 
     if ( m_enableAnimation ) {
         // add new animations
@@ -695,13 +693,13 @@ void GameScene::drawBackground( QPainter* painter, const QRectF& rect )
             // cache the background pixmap locally in order to reduce the spritePixmap traffic when resizing
             static QByteArray theme_pre( m_renderer.theme()->identifier() );
             static QSize size_pre( rect.toRect().size() );
-            static QPixmap pix( m_renderer.spritePixmap( QLatin1String( "BACKGROUND" ), size_pre ) );
+            static QPixmap pix( m_renderer.spritePixmap( QStringLiteral( "BACKGROUND" ), size_pre ) );
             QSize size_offset = size_pre - rect.toRect().size();
             if ( size_offset.width() < -100 || size_offset.height() < -100 || theme_pre != m_renderer.theme()->identifier() ) {
                 qWarning() << "export";
                 theme_pre = m_renderer.theme()->identifier();
                 size_pre = rect.toRect().size();
-                pix = m_renderer.spritePixmap( QLatin1String( "BACKGROUND" ), size_pre );
+                pix = m_renderer.spritePixmap( QStringLiteral( "BACKGROUND" ), size_pre );
                 painter->drawPixmap( rect.topLeft(), pix );
             }
             else {
